@@ -27,6 +27,7 @@ from layman.overlays.source import require_supported
 #from layman.utils import path, delete_empty_directory
 from layman.compatibility   import encode
 from layman.utils           import verify_overlay_src
+from layman.mounter         import Mounter
 
 if sys.hexversion >= 0x30200f0:
     STR = str
@@ -68,6 +69,10 @@ class LaymanAPI(object):
         self._error_messages = []
         self.sync_results = []
 
+        self.config.set_option('mounts', Mounter(self._get_installed_db,
+                                                 self.get_installed,
+                                                 config=self.config))
+
 
     def is_repo(self, ovl):
         """validates that the ovl given is a known repo id
@@ -122,7 +127,7 @@ class LaymanAPI(object):
                     self._get_installed_db().select(ovl))
             except Exception as e:
                 self._error(
-                        "Exception caught disabling repository '"+ovl+
+                        "Exception caught removing repository '"+ovl+
                             "':\n"+str(e))
             results.append(success)
             self.get_installed(dbreload=True)
@@ -155,7 +160,7 @@ class LaymanAPI(object):
                 success = self._get_installed_db().add(
                     self._get_remote_db().select(ovl))
             except Exception as e:
-                self._error("Exception caught enabling repository '"+ovl+
+                self._error("Exception caught installing repository '"+ovl+
                     "' : "+str(e))
             results.append(success)
             self.get_installed(dbreload=True)
@@ -183,6 +188,56 @@ class LaymanAPI(object):
         return success
 
 
+    def disable_repos(self, repos, update_news=False):
+        repos = self._check_repo_type(repos, "disable_repo")
+        results = []
+        for ovl in repos:
+            if not self.is_repo(ovl):
+                self.output.error(UnknownOverlayMessage(ovl))
+                result.append(False)
+                continue
+            success = False
+            try:
+                success = self._get_installed_db().disable(
+                    self._get_installed_db().select(ovl))
+            except Exception as e:
+                self._error('Exception caught disabling repository "%(repo)s"'\
+                    ': %(err)s' % ({'repo': ovl, 'err': e}))
+            results.append(success)
+            self.get_installed(dbreload=True)
+        if (True in results) and update_news:
+            self.update_news(repos)
+
+        if False in results:
+            return False
+        return True
+
+
+    def enable_repos(self, repos, update_news=False):
+        repos = self._check_repo_type(repos, "enable_repo")
+        results = []
+        for ovl in repos:
+            if not self.is_repo(ovl):
+                self.output.error(UnknownOverlayMessage(ovl))
+                result.append(False)
+                continue
+            success = False
+            try:
+                success = self._get_installed_db().enable(
+                    self._get_installed_db().select(ovl))
+            except Exception as e:
+                self._error('Exception caught enabling repository "%(repo)s"'\
+                    ': %(err)s' % ({'repo': ovl, 'err': e}))
+            results.append(success)
+            self.get_installed(dbreload=True)
+        if (True in results) and update_news:
+            self.update_news(repos)
+
+        if False in results:
+            return False
+        return True
+
+
     def get_all_info(self, repos, local=False):
         """retrieves the recorded information about the repo(s)
         specified by repo-id
@@ -234,7 +289,7 @@ class LaymanAPI(object):
                     'owner_email': overlay.owner_email,
                     'homepage': overlay.homepage,
                     'irc': overlay.irc,
-                    'description': overlay.description,
+                    'description': [e for e in overlay.descriptions],
                     'feeds': overlay.feeds,
                     'sources': [(e.src, e.type, e.branch) \
                         for e in overlay.sources],
@@ -333,7 +388,7 @@ class LaymanAPI(object):
                   '\n'\
                   '  %(remote_type)s\n'\
                   '\n'\
-                  'the overlay will be readded using %(remote_name)s' %\
+                  'the overlay will be readded using %(remote_type)s' %\
                   ({
                       'repo_name': odb.name,
                       'current_type': current_type,
@@ -354,9 +409,8 @@ class LaymanAPI(object):
         current_src = odb.sources[0].src
         (available_srcs, valid) = verify_overlay_src(current_src,
             set(e.src for e in ordb.sources))
-            
+
         if ordb and odb and not valid:
-            update_url = True
             if len(available_srcs) == 1:
                 plural = ''
                 candidates = '  %s' % tuple(available_srcs)[0]
@@ -375,15 +429,15 @@ class LaymanAPI(object):
                   '\n'\
                   'as correct location%(plural)s.\n'\
                   '\n'\
-                  'Repo: "%(repo_name)s" will be updated...' %\
+                  'Repo: "%(repo_name)s" was automatically updated...' %\
                   ({
                      'repo_name':odb.name,
                      'current_src':current_src,
                      'candidates':candidates,
                      'plural':plural,
                   })
-            return True, msg
-        return False, ''
+            return True, msg, available_srcs
+        return False, '', available_srcs
 
     def sync(self, repos, output_results=True, update_news=False):
         """syncs the specified repo(s) specified by repos
@@ -426,26 +480,34 @@ class LaymanAPI(object):
                 message = 'Overlay "%s" could not be found in the remote lists.\n' \
                         'Please check if it has been renamed and re-add if necessary.' % ovl
                 warnings.append((ovl, message))
+                (diff_type, update_url) = (False, False)
             else:
                 self.output.debug("API.sync(); else: self._get_remote_db().select(ovl)", 5)
 
                 (diff_type, type_msg) = self._verify_overlay_type(odb, ordb)
-                (update_url, url_msg) = self._verify_overlay_source(odb, ordb)
+                (update_url, url_msg, available_srcs) = self._verify_overlay_source(odb, ordb)
+
+                try:
+                    if diff_type:
+                        self.output.debug("API.sync(); starting API.readd_repos(ovl)", 5)
+                        warnings.append((ovl, type_msg))
+                        self.readd_repos(ovl)
+                        success.append((ovl, 'Successfully readded overlay "' + ovl + '".'))
+                    else:
+                        if update_url:
+                            self.output.debug("API.sync() starting db.update(ovl)", 5)
+                            warnings.append((ovl, url_msg))
+                            update_success = db.update(ordb, available_srcs)
+                            if not update_success:
+                                self.output.warn('Failed to update repo...readding', 2)
+                                self.readd_repos(ovl)
+                except Exception as error:
+                    self.output.warn('Failed to perform overlay type or url updates', 2)
+                    self.output.warn('    for Overlay: %s' % ovl, 2)
+                    self.output.warn('    Error was: %s' % str(error))
+                    continue
 
             try:
-                if diff_type:
-                    self.output.debug("API.sync(); starting API.readd_repos(ovl)", 5)
-                    warnings.append((ovl, type_msg))
-                    self.readd_repos(ovl)
-                    success.append((ovl, 'Successfully readded overlay "' + ovl + '".'))
-                else:
-                    if update_url:
-                        self.output.debug("API.sync() starting db.update(ovl)", 5)
-                        warnings.append((ovl, url_msg))
-                        update_success = db.update(ordb, available_srcs)
-                        if not update_success:
-                            self.output.warn('Failed to update repo...readding', 2)
-                            self.readd_repos(ovl)
                     self.output.debug("API.sync(); starting db.sync(ovl)", 5)
                     db.sync(ovl)
                     success.append((ovl,'Successfully synchronized overlay "' + ovl + '".'))
@@ -482,59 +544,10 @@ class LaymanAPI(object):
 
 
     def fetch_remote_list(self):
-        """Fetches the latest remote overlay list
+        """
+        Fetches the latest remote overlay list.
 
-
-        >>> import os
-        >>> here = os.path.dirname(os.path.realpath(__file__))
-        >>> import tempfile
-        >>> tmpdir = tempfile.mkdtemp(prefix="laymantmp_")
-        >>> cache = os.path.join(tmpdir, 'cache')
-        >>> from layman.config import OptionConfig
-        >>> opts = {'overlays' :
-        ...           ['file://' + here + '/tests/testfiles/global-overlays.xml'],
-        ...           'cache' : cache,
-        ...           'nocheck'    : 'yes',
-        ...           'proxy' : None,
-        ...           'svn_command':'/usr/bin/svn',
-        ...           'rsync_command':'/usr/bin/rsync'}
-        >>> config = OptionConfig(opts)
-        >>> config.set_option('quietness', 3)
-        >>> api = LaymanAPI(config)
-        >>> api.fetch_remote_list()
-        True
-        >>> api.get_errors()
-        []
-        >>> filename = api._get_remote_db().filepath(config['overlays'])+'.xml'
-        >>> b = fileopen(filename, 'r')
-        >>> b.readlines()[24]
-        '      A collection of ebuilds from Gunnar Wrobel [wrobel@gentoo.org].\\n'
-
-        >>> b.close()
-
-        >>> api.get_available()
-        ['wrobel', 'wrobel-stable']
-        >>> all = api.get_all_info('wrobel')
-        >>> info = all['wrobel']
-        >>> info['status']
-        'official'
-        >>> info['description']
-        'Test'
-        >>> info['sources']
-        [('https://overlays.gentoo.org/svn/dev/wrobel', 'Subversion', None)]
-
-        #{'wrobel': {'status': 'official',
-        #'owner_name': None, 'description': 'Test',
-        #'src_uris': <generator object source_uris at 0x167c3c0>,
-        #'owner_email': 'nobody@gentoo.org',
-        #'quality': 'experimental', 'name': 'wrobel', 'supported': True,
-        #'src_types': <generator object source_types at 0x167c370>,
-        #'official': True,
-        #'priority': 10, 'feeds': [], 'irc': None, 'homepage': None}}
-
-        >>> os.unlink(filename)
-        >>> import shutil
-        >>> shutil.rmtree(tmpdir)
+        @rtype bool: reflects success/failure to fetch remote list.
         """
 
         try:
@@ -617,12 +630,25 @@ class LaymanAPI(object):
     def supported_types(self):
         """returns a dictionary of all repository types,
         with boolean values"""
+        here = os.path.dirname(os.path.realpath(__file__))
+        modpath = os.path.join('overlays', 'modules')
+        modules = os.listdir(os.path.join(here, modpath))
+
         cmds = [x for x in self.config.keys() if '_command' in x]
         supported = {}
         for cmd in cmds:
             type_key = cmd.split('_')[0]
-            supported[type_key] = require_supported(
-                [(self.config[cmd],type_key, '')], self.output.warn)
+            # The module dir might be named differently from the type_key.
+            # ex.) g-common and g-sorcery are named g_common and g_sorcery.
+            module = type_key.replace('-', '_')
+
+            # Don't bother executing require_supported() if the user didn't
+            # bring in support for the overlay type in the first place.
+            if module in modules:
+                supported[type_key] = require_supported(
+                    [(self.config[cmd],type_key, '')], self.output.warn)
+            else:
+                supported[type_key] = False
         return supported
 
 
