@@ -82,14 +82,6 @@ class BareConfig(object):
         ):
         '''
         Creates a bare config with defaults and a few output options.
-
-        >>> a = BareConfig()
-        >>> a['overlays']
-        'https://api.gentoo.org/overlays/repositories.xml'
-        >>> sorted(a.keys())
-        ['bzr_addopts', 'bzr_command', 'bzr_postsync', 'bzr_syncopts', 'cache', 'config', 'configdir', 'custom_news_func', 'custom_news_pkg', 'cvs_addopts', 'cvs_command', 'cvs_postsync', 'cvs_syncopts', 'darcs_addopts', 'darcs_command', 'darcs_postsync', 'darcs_syncopts', 'g-common_command', 'g-common_generateopts', 'g-common_postsync', 'g-common_syncopts', 'git_addopts', 'git_command', 'git_email', 'git_postsync', 'git_syncopts', 'git_user', 'installed', 'local_list', 'make_conf', 'mercurial_addopts', 'mercurial_command', 'mercurial_postsync', 'mercurial_syncopts', 'news_reporter', 'nocheck', 'nocolor', 'output', 'overlay_defs', 'overlays', 'proxy', 'quiet', 'quietness', 'rsync_command', 'rsync_postsync', 'rsync_syncopts', 'stderr', 'stdin', 'stdout', 'storage', 'svn_addopts', 'svn_command', 'svn_postsync', 'svn_syncopts', 't/f_options', 'tar_command', 'tar_postsync', 'umask', 'verbose', 'width']
-        >>> a.get_option('nocheck')
-        True
         '''
 
         if root is None:
@@ -105,11 +97,12 @@ class BareConfig(object):
             'local_list': '%(storage)s/overlays.xml',
             'installed': '%(storage)s/installed.xml',
             'auto_sync': 'No',
+            'check_official': 'Yes',
             'conf_type': 'make.conf',
             'require_repoconfig': 'Yes',
-            'clean_tar': 'yes',
+            'clean_archive': 'yes',
             'make_conf' : '%(storage)s/make.conf',
-            'repos_conf': '/etc/portage/repos.conf/layman.conf',
+            'repos_conf': path([self.root, EPREFIX,'/etc/portage/repos.conf/layman.conf']),
             'conf_module': ['make_conf', 'repos_conf'],
             'nocheck'   : 'yes',
             'http_proxy'     : '',
@@ -130,10 +123,12 @@ class BareConfig(object):
             'g-common_command': path([self.root, EPREFIX,'/usr/bin/g-common']),
             'g-sorcery_command': path([self.root, EPREFIX,'/usr/bin/g-sorcery']),
             'mercurial_command': path([self.root, EPREFIX,'/usr/bin/hg']),
+            # left blank due to squashfs only needing to mount the image.
+            'squashfs_command': '',
             'rsync_command': path([self.root, EPREFIX,'/usr/bin/rsync']),
             'svn_command': path([self.root, EPREFIX,'/usr/bin/svn']),
             'tar_command': path([self.root, EPREFIX,'/bin/tar']),
-            't/f_options': ['clean_tar', 'nocheck', 'require_repoconfig'],
+            't/f_options': ['check_official', 'clean_archive', 'nocheck', 'require_repoconfig'],
             'bzr_addopts' : '',
             'bzr_syncopts' : '',
             'cvs_addopts' : '',
@@ -145,6 +140,8 @@ class BareConfig(object):
             'mercurial_addopts' : '',
             'mercurial_syncopts' : '',
             'rsync_syncopts' : '',
+            'squashfs_addopts': '',
+            'squashfs_syncopts': '',
             'svn_addopts' : '',
             'svn_syncopts' : '',
             'g-common_generateopts' : '',
@@ -157,6 +154,7 @@ class BareConfig(object):
             'git_postsync' : '',
             'mercurial_postsync' : '',
             'rsync_postsync' : '',
+            'squashfs_postsync': '',
             'svn_postsync' : '',
             'tar_postsync' : '',
             'g-common_postsync' : '',
@@ -296,13 +294,14 @@ class BareConfig(object):
             elif os.getenv(proxy):
                 proxies[proxy.split('_')[0]] = os.getenv(proxy)
         if self.config and proxies == {}:
-            self.output.debug("Warning: unable to determine proxies.", 6)
+            self._options['output'].debug("Warning: unable to determine prox" +
+                                          "ies.", 6)
 
         return proxies
 
 
 class OptionConfig(BareConfig):
-    """This subclasses BareCongig adding functions to make overriding
+    """This subclasses BareConfig adding functions to make overriding
     or resetting defaults and/or setting options much easier
     by using dictionaries.
     """
@@ -311,19 +310,14 @@ class OptionConfig(BareConfig):
         """
         @param options: dictionary of {'option': value, ...}
         @rtype OptionConfig class instance.
-
-        >>> options = {"overlays": ["http://www.gentoo-overlays.org/repositories.xml"]}
-        >>> new_defaults = {"configdir": "/etc/test-dir"}
-        >>> a = OptionConfig(options=options, defaults=new_defaults)
-        >>> a['overlays']
-        'http://www.gentoo-overlays.org/repositories.xml'
-        >>> a["configdir"]
-        '/etc/test-dir'
-        >>> sorted(a.keys())
-        ['bzr_addopts', 'bzr_command', 'bzr_postsync', 'bzr_syncopts', 'cache', 'config', 'configdir', 'custom_news_func', 'custom_news_pkg', 'cvs_addopts', 'cvs_command', 'cvs_postsync', 'cvs_syncopts', 'darcs_addopts', 'darcs_command', 'darcs_postsync', 'darcs_syncopts', 'g-common_command', 'g-common_generateopts', 'g-common_postsync', 'g-common_syncopts', 'git_addopts', 'git_command', 'git_email', 'git_postsync', 'git_syncopts', 'git_user', 'installed', 'local_list', 'make_conf', 'mercurial_addopts', 'mercurial_command', 'mercurial_postsync', 'mercurial_syncopts', 'news_reporter', 'nocheck', 'nocolor', 'output', 'overlay_defs', 'overlays', 'proxy', 'quiet', 'quietness', 'rsync_command', 'rsync_postsync', 'rsync_syncopts', 'stderr', 'stdin', 'stdout', 'storage', 'svn_addopts', 'svn_command', 'svn_postsync', 'svn_syncopts', 't/f_options', 'tar_command', 'tar_postsync', 'umask', 'verbose', 'width']
         """
         BareConfig.__init__(self, root=root)
 
+        if options and 'output' in options:
+            self.output = options['output']
+        else:
+            self.output = Message()
+
         self.update_defaults(defaults)
 
         self.update(options)
@@ -340,7 +334,7 @@ class OptionConfig(BareConfig):
             if 'quiet' in keys:
                 self.set_option('quiet', options['quiet'])
                 options.pop('quiet')
-            if 'quietness' in keys and not options['quiet']:
+            elif 'quietness' in keys:
                 self._set_quietness(options['quietness'])
                 options.pop('quietness')
             self._options.update(options)
