@@ -29,7 +29,7 @@ __version__ = "$Id: db.py 309 2007-04-09 16:23:38Z wrobel $"
 
 import os, os.path
 
-from   layman.utils             import path, delete_empty_directory
+from   layman.utils             import path, delete_empty_directory, get_ans
 from   layman.dbbase            import DbBase
 from   layman.repoconfmanager   import RepoConfManager
 
@@ -77,6 +77,32 @@ class DB(DbBase):
     def _broken_catalog_hint(self):
         return ''
 
+
+    def _check_official(self, overlay):
+        '''
+        Prompt user to see if they want to install unofficial overlays.
+
+        @params overlay: layman.overlays.Overlay object.
+        @rtype bool: reflect the user's decision to install overlay.
+        '''
+        if self.config['check_official'] and not overlay.status == 'official':
+            msg = 'Overlay "%(repo)s" is not an official. Continue install?'\
+                  ' [y/n]: ' % {'repo': overlay.name}
+            if not get_ans(msg, color='green'):
+                msg = 'layman will not add "%(repo)s", due to user\'s'\
+                      ' decision\nto not install unofficial overlays.'\
+                      % {'repo': overlay.name}
+                hint = 'Hint: To remove this check, set "check_official"'\
+                       ' to "No"\nin your layman.cfg.'
+                self.output.warn(msg)
+                self.output.notice('')
+                self.output.warn(hint)
+                return False
+            else:
+                return True
+        return True
+
+
     def add(self, overlay):
         '''
         Add an overlay to the local list of overlays.
@@ -127,6 +153,8 @@ class DB(DbBase):
         '''
 
         if overlay.name not in self.overlays.keys():
+            if not self._check_official(overlay):
+                return False
             result = overlay.add(self.config['storage'])
             if result == 0:
                 if 'priority' in self.config.keys():
@@ -134,7 +162,9 @@ class DB(DbBase):
                 self.overlays[overlay.name] = overlay
                 self.write(self.path)
                 repo_ok = self.repo_conf.add(overlay)
-                return repo_ok
+                if False in repo_ok:
+                    return False
+                return True
             else:
                 mdir = path([self.config['storage'], overlay.name])
                 delete_empty_directory(mdir, self.output)
@@ -214,30 +244,67 @@ class DB(DbBase):
 
         if overlay.name in self.overlays.keys():
             overlay.delete(self.config['storage'])
-            self.repo_conf.delete(overlay)
+            repo_ok = self.repo_conf.delete(overlay)
             del self.overlays[overlay.name]
             self.write(self.path)
         else:
             self.output.error('No local overlay named "' + overlay.name + '"!')
             return False
+        if False in repo_ok:
+            return False
         return True
 
 
+    def disable(self, overlay):
+        if overlay.name in self.overlays.keys():
+            result = self.repo_conf.disable(overlay)
+        else:
+            self.output.error('No local overlay named "%(repo)s"!'\
+                % ({'repo': overlay.name}))
+            return False
+        msg = 'Overlay %(repo)s has been disabled.\n'\
+              'All ebuilds in this overlay will not be recognized by portage.'\
+              % ({'repo': overlay.name})
+        if result:
+            self.output.warn(msg)
+        return result
+
+
+    def enable(self, overlay):
+        if overlay.name in self.overlays.keys():
+            result = self.repo_conf.enable(overlay)
+        else:
+            self.output.error('No local overlay named "%(repo)s"!'\
+                % ({'repo': overlay.name}))
+            return False
+        msg = 'Overlay %(repo)s has been enabled.\n'\
+              'All ebuilds in this overlay will now be recognized by portage.'\
+              % ({'repo': overlay.name})
+        if result:
+            self.output.info(msg)
+        return result
+
+
     def update(self, overlay, available_srcs):
         '''
         Updates the overlay source via the available source(s).
-        
+
         @params overlay: layman.overlay.Overlay object.
         @params available_srcs: set of available source URLs.
         '''
 
         source, result = self.overlays[overlay.name].update(self.config['storage'],
                                                     available_srcs)
+        result = [result]
         self.overlays[overlay.name].sources = source
-        self.repo_conf.update(self.overlays[overlay.name])
+        result.extend(self.repo_conf.update(self.overlays[overlay.name]))
         self.write(self.path)
 
-        return result
+        if False in result:
+            return False
+        return True
+
+
 
     def sync(self, overlay_name):
         '''Synchronize the given overlay.'''
