@@ -6,15 +6,22 @@
  Distributed under the terms of the GNU General Public License v2
 """
 
+from __future__ import unicode_literals
+from __future__ import print_function
 
 __version__ = "0.1"
 
 
 import sys
 
-from layman.constants import codes, INFO_LEVEL, WARN_LEVEL, DEBUG_LEVEL, OFF
+from layman.constants import codes, INFO_LEVEL, WARN_LEVEL, NOTE_LEVEL, DEBUG_LEVEL, OFF
 from layman.compatibility import encode
 
+# py3.2
+if sys.hexversion >= 0x30200f0:
+    from io import IOBase as BUILTIN_FILE_TYPE
+else:
+    BUILTIN_FILE_TYPE=file
 
 class MessageBase(object):
     """Base Message class helper functions and variables
@@ -25,17 +32,18 @@ class MessageBase(object):
                  err = sys.stderr,
                  info_level = INFO_LEVEL,
                  warn_level = WARN_LEVEL,
+                 note_level = NOTE_LEVEL,
                  col = True,
                  error_callback=None
                  ):
         # Where should the error output go? This can also be a file
-        if isinstance(err, file):
+        if isinstance(err, BUILTIN_FILE_TYPE):
             self.error_out = err
         else:
             raise Exception("MessageBase: input parameter 'err' must be of type: file")
 
         # Where should the normal output go? This can also be a file
-        if isinstance(out, file):
+        if isinstance(out, BUILTIN_FILE_TYPE):
             self.std_out = out
         else:
             raise Exception("MessageBase: input parameter 'out' must be of type: file")
@@ -46,6 +54,9 @@ class MessageBase(object):
         # The higher the level the more information you will get
         self.info_lev = info_level
 
+        # The higher the level the more information you will get
+        self.note_lev = note_level
+
         # Should the output be colored?
         self.color_func = None
         self.set_colorize(col)
@@ -81,6 +92,10 @@ class MessageBase(object):
         self.warn_lev = warn_level
 
 
+    def set_note_level(self, note_level = NOTE_LEVEL):
+        self.note_lev = note_level
+
+
     def set_debug_level(self, debugging_level = DEBUG_LEVEL):
         self.debug_lev = debugging_level
 
@@ -103,12 +118,13 @@ class Message(MessageBase):
                  err = sys.stderr,
                  info_level = INFO_LEVEL,
                  warn_level = WARN_LEVEL,
+                 note_level = NOTE_LEVEL,
                  col = True,
                  error_callback = None
                 ):
 
         MessageBase.__init__(self, out, err, info_level, warn_level,
-            col, error_callback)
+            note_level, col, error_callback)
 
 
     ## Output Functions
@@ -124,11 +140,15 @@ class Message(MessageBase):
             return
 
         for i in info.split('\n'):
-            print  >> self.std_out, self.color_func('yellow', 'DEBUG: ') + i
+            print(self.color_func('yellow', 'DEBUG: ') + i, file=self.std_out)
 
 
-    def notice (self, note):
-        print >> self.std_out, note
+    def notice (self, note, level = NOTE_LEVEL):
+
+        if level > self.note_lev:
+            return
+
+        print(note, file=self.std_out)
 
 
     def info (self, info, level = INFO_LEVEL):
@@ -140,7 +160,7 @@ class Message(MessageBase):
             return
 
         for i in info.split('\n'):
-            print  >> self.std_out, " %s %s" % (self.color_func('green', '*'),i)
+            print(" %s %s" % (self.color_func('green', '*'),i), file=self.std_out)
 
 
     def status (self, message, status, info = 'ignored'):
@@ -154,7 +174,7 @@ class Message(MessageBase):
             return
 
         for i in lines[0:-1]:
-            print >> self.std_out, " %s %s" % (self.color_func('green', '*'),i)
+            print(" %s %s" % (self.color_func('green', '*'),i), file=self.std_out)
 
         i = lines[-1]
 
@@ -168,8 +188,8 @@ class Message(MessageBase):
         else:
             result = '[' + self.color_func('yellow', info) + ']'
 
-        print >> " %s %s %s %S" % (self.color_func('green', '*'), i,
-            ('.' * (58 - len(i))), result)
+        print(file=" %s %s %s %S" % (self.color_func('green', '*'), i,
+            ('.' * (58 - len(i))), result))
 
 
     def warn (self, warn, level = WARN_LEVEL):
@@ -181,10 +201,10 @@ class Message(MessageBase):
             return
 
         for i in warn.split('\n'):
-            print >> self.std_out, " %s %s" % (self.color_func('yellow', '*'),i)
+            print(" %s %s" % (self.color_func('yellow', '*'),i), file=self.std_out)
 
 
-    def error (self, error):
+    def error (self, error, level = None):
 
         if type(error) != str:#not in types.StringTypes:
             error = encode(error)
@@ -195,7 +215,7 @@ class Message(MessageBase):
             # "layman -L |& less".
             self.std_out.flush()
             self.error_out.flush()
-            print >> self.std_out, " %s %s" % (self.color_func('red', '*'), i)
+            print(" %s %s" % (self.color_func('red', '*'), i), file=self.std_out)
             self.std_out.flush()
         self.do_error_callback(error)
 
