@@ -35,38 +35,16 @@ import codecs
 import locale
 import xml.etree.ElementTree as ET # Python 2.5
 
-from layman.utils import pad, terminal_width, get_encoding, encoder
-from layman.compatibility import encode
-
-from   layman.overlays.bzr       import BzrOverlay
-from   layman.overlays.darcs     import DarcsOverlay
-from   layman.overlays.git       import GitOverlay
-from   layman.overlays.g_common  import GCommonOverlay
-from   layman.overlays.g_sorcery import GSorceryOverlay
-from   layman.overlays.mercurial import MercurialOverlay
-from   layman.overlays.cvs       import CvsOverlay
-from   layman.overlays.svn       import SvnOverlay
-from   layman.overlays.rsync     import RsyncOverlay
-from   layman.overlays.tar       import TarOverlay
+from  layman.compatibility import encode
+from  layman.module        import Modules, InvalidModuleName
+from  layman.utils         import pad, terminal_width, get_encoding, encoder
 
 #===============================================================================
 #
 # Constants
 #
 #-------------------------------------------------------------------------------
-
-OVERLAY_TYPES = dict((e.type_key, e) for e in (
-    GitOverlay,
-    GCommonOverlay,
-    GSorceryOverlay,
-    CvsOverlay,
-    SvnOverlay,
-    RsyncOverlay,
-    TarOverlay,
-    BzrOverlay,
-    MercurialOverlay,
-    DarcsOverlay
-))
+MOD_PATH = path = os.path.join(os.path.dirname(__file__), 'modules')
 
 QUALITY_LEVELS = 'core|stable|testing|experimental|graveyard'.split('|')
 
@@ -78,32 +56,11 @@ class Overlay(object):
 
     def __init__(self, config, xml=None, ovl_dict=None,
         ignore = 0):
-        '''
-        >>> here = os.path.dirname(os.path.realpath(__file__))
-        >>> import xml.etree.ElementTree as ET # Python 2.5
-        >>> document =ET.parse(here + '/../tests/testfiles/global-overlays.xml')
-        >>> overlays = document.findall('overlay') + document.findall('repo')
-        >>> from layman.output import Message
-        >>> output = Message()
-        >>> a = Overlay({'output': output}, overlays[0])
-        >>> a.name
-        'wrobel'
-        >>> a.is_official()
-        True
-        >>> list(a.source_uris())
-        ['https://overlays.gentoo.org/svn/dev/wrobel']
-        >>> a.owner_email
-        'nobody@gentoo.org'
-        >>> a.description
-        'Test'
-        >>> a.priority
-        10
-        >>> b = Overlay({'output': output}, overlays[1])
-        >>> b.is_official()
-        False
-        '''
         self.config = config
         self.output = config['output']
+        self.module_controller = Modules(path=MOD_PATH,
+                                         namepath='layman.overlays.modules',
+                                         output=self.output)
         self._encoding_ = get_encoding(self.output)
 
         if xml is not None:
@@ -130,14 +87,6 @@ class Overlay(object):
             raise Exception('Overlay from_xml(), "' + self.name + \
                 'is missing a "name" entry!')
 
-        _branch = xml.find('branch')
-        if _branch != None and _branch.text:
-            self.branch = encode(_branch.text.strip())
-        elif 'branch' in xml.attrib:
-            self.branch = encode(xml.attrib['branch'])
-        else:
-            self.branch = ''
-
         _sources = xml.findall('source')
         # new xml format
         if _sources != []:
@@ -150,13 +99,21 @@ class Overlay(object):
             del s
 
         def create_overlay_source(source_elem):
+            _branch = ''
             _type = source_elem.attrib['type']
+            self.ovl_type = _type
+            if 'branch' in source_elem.attrib:
+                _branch = source_elem.attrib['branch']
+
             try:
-                _class = OVERLAY_TYPES[_type]
-            except KeyError:
-                raise Exception('Overlay from_xml(), "' + self.name + \
-                    'Unknown overlay type "%s"!' % _type)
+                _class = self.module_controller.get_class(_type)
+            except InvalidModuleName:
+                _class = self.module_controller.get_class('stub')
+
             _location = encode(strip_text(source_elem))
+
+            self.branch = _branch
+
             return _class(parent=self, config=self.config,
                 _location=_location, ignore=ignore)
 
@@ -191,13 +148,14 @@ class Overlay(object):
                 self.output.warn('Overlay "' + self.name + '" is missing a '
                          '"owner.email" entry!', 4)
 
-        _desc = xml.find('description')
+        _desc = xml.findall('description')
         if _desc != None:
-            d = WHITESPACE_REGEX.sub(' ', strip_text(_desc))
-            self.description = encode(d)
-            del d
+            self.descriptions = []
+            for d in _desc:
+                d = WHITESPACE_REGEX.sub(' ', strip_text(d))
+                self.descriptions.append(encode(d))
         else:
-            self.description = ''
+            self.descriptions = ['']
             if not ignore:
                 raise Exception('Overlay  from_xml(), "' + self.name + \
                     '" is missing a description" entry!')
@@ -240,9 +198,9 @@ class Overlay(object):
 
 
     def from_dict(self, overlay, ignore):
-        """Process an xml overlay definition
+        """Process an overlay dictionary definition
         """
-        self.output.debug("Overlay from_dict(); overlay" + str(overlay))
+        self.output.debug("Overlay from_dict(); overlay" + str(overlay), 6)
         _name = overlay['name']
         if _name != None:
             self.name = encode(_name)
@@ -258,25 +216,31 @@ class Overlay(object):
 
         def create_dict_overlay_source(source_):
             _src, _type, _sub = source_
+            self.ovl_type = _type
             try:
-                _class = OVERLAY_TYPES[_type]
-            except KeyError:
-                raise Exception('Overlay from_dict(), "' + self.name +
-                    'Unknown overlay type "%s"!' % _type)
+                _class = self.module_controller.get_class(_type)
+            except InvalidModuleName:
+                _class = self.module_controller.get_class('stub')
+
             _location = encode(_src)
+            if _sub:
+                self.branch = encode(_sub)
+            else:
+                self.branch = None
+
             return _class(parent=self, config=self.config,
                 _location=_location, ignore=ignore)
 
         self.sources = [create_dict_overlay_source(e) for e in _sources]
 
-        _owner = overlay['owner_name']
-        if _owner == None:
-            self.owner_name = None
-            _email = None
-        else:
+        if 'owner_name' in overlay:
+            _owner = overlay['owner_name']
             self.owner_name = encode(_owner)
+        else:
+            self.owner_name = None
+
+        if 'owner_email' in overlay:
             _email = overlay['owner_email']
-        if _email != None:
             self.owner_email = encode(_email)
         else:
             self.owner_email = None
@@ -287,13 +251,14 @@ class Overlay(object):
                 self.output.warn('Overlay from_dict(), "' + self.name +
                     '" is missing an "owner.email" entry!', 4)
 
-        _desc = overlay['description']
-        if _desc != None:
-            d = WHITESPACE_REGEX.sub(' ', _desc)
-            self.description = encode(d)
-            del d
+        if 'descriptions' in overlay:
+            self.descriptions = []
+            _descs = overlay['descriptions']
+            for d in _descs:
+                d = WHITESPACE_REGEX.sub(' ', d)
+                self.descriptions.append(encode(d))
         else:
-            self.description = ''
+            self.descriptions = ['']
             if not ignore:
                 raise Exception('Overlay from_dict(), "' + self.name +
                     '" is missing a "description" entry!')
@@ -301,47 +266,43 @@ class Overlay(object):
                 self.output.warn('Overlay from_dict(), "' + self.name +
                     '" is missing a "description" entry!', 4)
 
-        if overlay['status']:
+        if 'status' in overlay:
             self.status = encode(overlay['status'])
         else:
             self.status = None
 
         self.quality = 'experimental'
-        if len(overlay['quality']):
+        if 'quality' in overlay:
             if overlay['quality'] in set(QUALITY_LEVELS):
                 self.quality = encode(overlay['quality'])
 
-        if overlay['priority']:
+        if 'priority' in overlay:
             self.priority = int(overlay['priority'])
         else:
             self.priority = 50
 
-        h = overlay['homepage']
-        if h != None:
-            self.homepage = encode(h)
+        if 'homepage' in overlay:
+            self.homepage = encode(overlay['homepage'])
         else:
             self.homepage = None
 
-        self.feeds = [encode(e) \
-            for e in overlay['feeds']]
+        if 'feeds' in overlay:
+            self.feeds = [encode(e) \
+                for e in overlay['feeds']]
+        else:
+            self.feeds = None
 
-        _irc = overlay['irc']
-        if _irc != None:
-            self.irc = encode(_irc)
+        if 'irc' in overlay:
+            self.irc = encode(overlay['irc'])
         else:
             self.irc = None
 
-        _branch = overlay['branch']
-        if _branch != None:
-            self.branch = encode(_branch)
-        else:
-            self.branch = None
         #xml = self.to_xml()
         # end of from_dict
 
 
     def __eq__(self, other):
-        for i in ('description', 'homepage', 'name', 'owner_email',
+        for i in ('descriptions', 'homepage', 'name', 'owner_email',
                 'owner_name', 'priority', 'status'):
             if getattr(self, i) != getattr(other, i):
                 return False
@@ -372,17 +333,15 @@ class Overlay(object):
         name = ET.Element('name')
         name.text = self.name
         repo.append(name)
-        desc = ET.Element('description')
-        desc.text = self.description
-        repo.append(desc)
+        for i in self.descriptions:
+            desc = ET.Element('description')
+            desc.text = i
+            repo.append(desc)
+            del desc
         if self.homepage != None:
             homepage = ET.Element('homepage')
             homepage.text = self.homepage
             repo.append(homepage)
-        if self.branch != None:
-            branch = ET.Element('branch')
-            branch.text = self.branch
-            repo.append(branch)
         if self.irc != None:
             irc = ET.Element('irc')
             irc.text = self.irc
@@ -397,7 +356,10 @@ class Overlay(object):
             owner_name.text = self.owner_name
             owner.append(owner_name)
         for i in self.sources:
-            source = ET.Element('source', type=i.__class__.type_key)
+            if not i.branch:
+                source = ET.Element('source', type=i.__class__.type_key)
+            else:
+                source = ET.Element('source', type=i.__class__.type_key, branch=i.branch)
             source.text = i.src
             repo.append(source)
             del source
@@ -405,11 +367,12 @@ class Overlay(object):
             # NOTE: Two loops on purpose so the
             # hooks are called with all sources in
             i.to_xml_hook(repo)
-        for i in self.feeds:
-            feed = ET.Element('feed')
-            feed.text = i
-            repo.append(feed)
-            del feed
+        if self.feeds != None:
+            for i in self.feeds:
+                feed = ET.Element('feed')
+                feed.text = i
+                repo.append(feed)
+                del feed
         return repo
 
 
@@ -478,24 +441,9 @@ class Overlay(object):
 
     def get_infostr(self):
         '''
-        >>> here = os.path.dirname(os.path.realpath(__file__))
-        >>> import xml.etree.ElementTree as ET # Python 2.5
-        >>> document =ET.parse(here + '/../tests/testfiles/global-overlays.xml')
-        >>> overlays = document.findall('overlay') + document.findall('repo')
-        >>> from layman.output import Message
-        >>> output = Message()
-        >>> a = Overlay({'output': output}, overlays[0])
-        >>> print a.get_infostr()
-        wrobel
-        ~~~~~~
-        Source  : https://overlays.gentoo.org/svn/dev/wrobel
-        Contact : nobody@gentoo.org
-        Type    : Subversion; Priority: 10
-        Quality : experimental
-        <BLANKLINE>
-        Description:
-          Test
-        <BLANKLINE>
+        Gives more detailed string of overlay information.
+
+        @rtype str: encoded overlay information.
         '''
 
         result = ''
@@ -524,12 +472,12 @@ class Overlay(object):
         result += 'Quality : ' + self.quality + '\n'
 
 
-        description = self.description
-        description = re.compile(' +').sub(' ', description)
-        description = re.compile('\n ').sub('\n', description)
-        result += '\nDescription:'
-        result += '\n  '.join(('\n' + description).split('\n'))
-        result += '\n'
+        for description in self.descriptions:
+            description = re.compile(' +').sub(' ', description)
+            description = re.compile('\n ').sub('\n', description)
+            result += '\nDescription:'
+            result += '\n  '.join(('\n' + description).split('\n'))
+            result += '\n'
 
         if self.homepage != None:
             link = self.homepage
@@ -553,15 +501,10 @@ class Overlay(object):
 
     def short_list(self, width = 0):
         '''
-        >>> here = os.path.dirname(os.path.realpath(__file__))
-        >>> import xml.etree.ElementTree as ET # Python 2.5
-        >>> document =ET.parse(here + '/../tests/testfiles/global-overlays.xml')
-        >>> overlays = document.findall('repo') + document.findall('overlay')
-        >>> from layman.output import Message
-        >>> output = Message()
-        >>> a = Overlay({'output': output}, overlays[0])
-        >>> print a.short_list(80)
-        wrobel                    [Subversion] (https://o.g.o/svn/dev/wrobel         )
+        Return a shortened list of overlay information.
+
+        @params width: int specifying terminal width.
+        @rtype str: string of overlay information.
         '''
         if len(self.name) > 25:
             name = self.name + "   ###\n"
