@@ -24,7 +24,7 @@ __version__ = '$Id: dtest.py 237 2006-09-05 21:18:54Z wrobel $'
 #
 #-------------------------------------------------------------------------------
 
-import unittest, doctest, sys
+import unittest, doctest
 
 # On module creation:
 
@@ -49,7 +49,9 @@ import unittest, doctest, sys
 # clean but no testing  : CN
 # unclean but no testing: UN
 
-import layman.action             #CT
+import layman.api                #CT
+import layman.argsparser         #CT
+import layman.cli                #CT
 import layman.config             #CT
 import layman.db                 #CT
 import layman.dbbase             #CT
@@ -65,8 +67,9 @@ import layman.overlays.tar       #CT
 
 def test_suite():
     return unittest.TestSuite((
-        doctest.DocTestSuite(layman.action),
+        doctest.DocTestSuite(layman.api),
         doctest.DocTestSuite(layman.config),
+        doctest.DocTestSuite(layman.argsparser),
         doctest.DocTestSuite(layman.db),
         doctest.DocTestSuite(layman.dbbase),
         doctest.DocTestSuite(layman.utils),
